@@ -68,7 +68,7 @@
 #' 
 #' # See https://tidymodels.github.io/embed/ for examples
 
-#' @importFrom recipes add_step step terms_select sel2char ellipse_check
+
 step_lencode_glm <-
   function(recipe,
            ...,
@@ -108,7 +108,7 @@ step_lencode_glm_new <-
     )
   }
 
-#' @importFrom recipes check_type
+
 #' @export
 prep.step_lencode_glm <- function(x, training, info = NULL, ...) {
   col_names <- terms_select(x$terms, info = info)
@@ -125,8 +125,7 @@ prep.step_lencode_glm <- function(x, training, info = NULL, ...) {
     id = x$id)
 }
 
-#' @importFrom stats as.formula glm binomial coef gaussian na.omit
-#' @importFrom dplyr bind_cols as_tibble
+
 glm_coefs <- function(x, y, ...) {
   fam <- if (is.factor(y[[1]])) binomial else gaussian
   form <- as.formula(paste0(names(y), "~ 0 + value"))
@@ -160,7 +159,7 @@ glm_coefs <- function(x, y, ...) {
 }
 
 
-#' @importFrom dplyr tibble mutate filter left_join %>% arrange 
+
 map_glm_coef <- function(dat, mapping) {
   new_val <- mapping$..value[mapping$..level == "..new"]
   dat <- dat %>% 
@@ -174,9 +173,7 @@ map_glm_coef <- function(dat, mapping) {
   dat$..value
 }
 
-#' @import rlang
-#' @importFrom recipes bake prep
-#' @importFrom purrr map
+
 #' @export
 bake.step_lencode_glm <- function(object, new_data, ...) {
   for (col in names(object$mapping))
@@ -185,7 +182,6 @@ bake.step_lencode_glm <- function(object, new_data, ...) {
   new_data
 }
 
-#' @importFrom recipes printer
 #' @export
 print.step_lencode_glm <-
   function(x, width = max(20, options()$width - 31), ...) {
@@ -194,8 +190,7 @@ print.step_lencode_glm <-
     invisible(x)
   }
 
-#' @importFrom dplyr bind_rows
-#' @importFrom recipes is_trained
+
 #' @rdname step_lencode_glm
 #' @param x A `step_lencode_glm` object.
 #' @export
@@ -218,6 +213,3 @@ tidy.step_lencode_glm <- function(x, ...) {
   res$id <- x$id
   res
 }
-
-#' @importFrom utils globalVariables
-utils::globalVariables(c("..level", "..order"))
