@@ -125,9 +125,11 @@
 #' library(modeldata)
 #' data(okc)
 #' 
-#' rec <- recipe(Class ~ age + location, data = okc) %>%
-#'   step_embed(location, outcome = vars(Class),
-#'              options = embed_control(epochs = 10))
+#' if (is_tf_available()) {
+#'   rec <- recipe(Class ~ age + location, data = okc) %>%
+#'     step_embed(location, outcome = vars(Class),
+#'                options = embed_control(epochs = 10))
+#' }
 #' 
 #' # See https://tidymodels.github.io/embed/ for examples
 
@@ -147,6 +149,9 @@ step_embed <-
            history = NULL,
            skip = FALSE,
            id = rand_id("lencode_bayes")) {
+    # warm start for tf to avoid a bug in tensorflow
+    is_tf_available()
+    
     if (is.null(outcome))
       rlang::abort("Please list a variable in `outcome`")
     add_step(
@@ -478,3 +483,22 @@ class2ind <- function (x)  {
   y
 }
 
+
+#' Test to see if tensorflow is available
+#' 
+#' @return A logical
+#' @examples 
+#' is_tf_available()
+#' @export
+is_tf_available <- function() {
+  capture.output(res <- try(tensorflow::tf_config(), silent = TRUE), file = NULL)
+  if (inherits(res, "try-error") | all(is.null(res))) {
+    return(FALSE)
+  } else {
+    if (!(any(names(res) == "available"))) {
+      return(FALSE)
+    }
+  }
+  res$available
+}
+
